#!/bin/sh

PKGI="fheroes2-pkg"
DIR="/usr/src/${PKGI}"
PKGG="fheroes2"

# Source debconf library.
. /usr/share/debconf/confmodule
db_version 2.0
db_get ${PKGI}/build
## $RET contains "true" if build is allowed in debconf.
[ "$RET" = "true" ] || exit 0

## get installed guest-package version
VERG="$(dpkg --status ${PKGG} 2>/dev/null | perl -0ne 'print $1 if m{^Status:\s+install\s+ok\s+installed}sm and m{^Version:\s+([0-9.-]+(?:\+svn\d+-\d+)*)}sm;')"

## get version of bundled "guest" package
VERGG=$(dpkg-parsechangelog -l/usr/share/${PKGI}/debian/changelog | sed -n 's/^Version: *//p')

## check if we have a newer version of guest package to install.
## package version is mangled to append '~local' to debian revision number
dpkg --compare-versions "${VERGG}~local" gt "${VERG}"
[ $? = 0 ] || exit 0

## we have newer package to build/install

## Check if this very version of guest package was previously installed.
## self-disable in debconf settings, if user manually removed it.
if [ -f "${DIR}/${PKGG}-${VERGG}.is-installed" ]; then
    rm "${DIR}/${PKGG}-${VERGG}.is-installed"
    db_set ${PKGI}/build false
    echo "${PKGI}: Package ${PKGG}-${VERGG} was removed, stop processing..."
    exit 0
fi

## check if DPKG database is locked
dpkg -i /dev/zero 2>/dev/null
if [ "$?" -eq 2 ]; then
    echo "${PKGI}: dpkg database is locked. You may need to use command \"sudo dpkg-reconfigure ${PKGI}\"."
    db_get fheroes2-pkg/post-invoke_hook
    if [ "$RET" = "true" ]; then
        echo "${PKGI}: Building and installation of package(s) [${PKGG}] postponed till after next APT operation."
    fi
    exit 0
fi

apt-get check >/dev/null 2>&1
if [ "$?" -ne 0 ]; then
    echo "${PKGI}: \`apt-get check\` failed, you may have broken packages. Aborting..."
    db_set ${PKGI}/build false
    exit 0
fi

set -e
mkdir -p ${DIR} || true

## download orig.tar
echo "${PKGI}: Downloading orig source..."
cd ${DIR} \
&& /usr/share/${PKGI}/debian/rules get-orig-source
echo "${PKGI}: Checking integrity..."
sha1sum --check --strict --quiet /usr/share/${PKGI}/*_${VERGG%%-*}.orig.tar.*.sha1
if [ $? != 0 ]; then
    rm -fv ${DIR}/*_${VERGG%%-*}.orig.tar.*
    echo "Source archive failed integrity check so it was deleted. Please try again."
    false
fi

## preparing to build
echo "${PKGI}: Unpacking and configuring..."
[ -d "${DIR}/build" ] && rm -rf ${DIR}/build
mkdir ${DIR}/build
cd ${DIR}/build
tar xf ../*_${VERGG%%-*}.orig.tar.* --strip-components 1
cp -r /usr/share/${PKGI}/debian .
## append '~local' to debian revision
perl -pi -e "s{[\d.]+-\d+\K}{~local}" debian/changelog
## inject ${PKGI} to guest package Depends to uninstall generated packages on installer remove.
perl -pi -e "s{^Depends:\K}{ ${PKGI}, }mg" debian/control

## building package
echo "${PKGI}: Building the package..."
dpkg-buildpackage -b -uc -j2

## installing
echo "${PKGI}: Installing..."
dpkg --install /usr/src/${PKGI}/*_${VERGG}~local_*.deb \
&& touch "${DIR}/${PKGG}-${VERGG}.is-installed" \
|| echo "${PKGI}: dpkg database is probably locked. Please try \"sudo dpkg-reconfigure ${PKGI}\"."

